##  Overview
**Note**
On November 17, 2025, tech categories in the reference catalog were updated to the latest [_version 5.0.1 of the TBM Taxonomy_![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.tbmcouncil.org%2Ftaxonomy%2F "https://www.tbmcouncil.org/taxonomy/"). To learn how to migrate your tech categories to this version, see [Migrating to the TBM Taxonomy Version 5.0.1 for Tech Categories](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories?locale=en-US&state=PRODUCTION&version=CLOUD "Migrate to the TBM Taxonomy version 5.0.1 to keep your tech categories in sync with the latest version.").
The TBM Taxonomy is a standardized classification system within the Technology Business Management (TBM) framework that categorizes cost sources, technologies, IT resources, applications, and services, promoting alignment among IT, finance, and business unit leaders. For more information on TBM, refer to the [website of the TBM Council![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.tbmcouncil.org%2F "https://www.tbmcouncil.org/").
Tech categories in the reference catalog facilitate the adoption of the TBM Council’s TBM Solutions layer version 5.0.1 as the standard taxonomy, which is recommended as a best-practice approach.
By using information available in the reference catalog, you can:
  * Understand and define your tech category taxonomy according to TBM's recommendations using the provided template
  * Import the TBM Taxonomy into your workspace and customize it to your needs
